setup method

Future<void> setup(
  1. String organizationId,
  2. String projectId,
  3. String publicKey, {
  4. Uri? configurationURL,
  5. String mode = 'strict',
  6. String? instanceId,
})

Initializes the TrustPin SDK with the given credentials.

When instanceId is null, the global default instance is used. When provided, a named instance is created or retrieved.

Implementation

Future<void> setup(
  String organizationId,
  String projectId,
  String publicKey, {
  Uri? configurationURL,
  String mode = 'strict',
  String? instanceId,
}) {
  throw UnimplementedError('setup() has not been implemented.');
}