error property
The verdict for a failure event, carrying the stable error code
(PINS_MISMATCH, ALL_PINS_EXPIRED, or DOMAIN_NOT_REGISTERED).
null for a success event.
Implementation
final TrustPinException? error;
The verdict for a failure event, carrying the stable error code
(PINS_MISMATCH, ALL_PINS_EXPIRED, or DOMAIN_NOT_REGISTERED).
null for a success event.
final TrustPinException? error;