TrustPinDioInterceptor class
A certificate pinning interceptor for the Dio HTTP client.
final dio = Dio();
dio.interceptors.add(TrustPinDioInterceptor());
final response = await dio.get('https://api.example.com/data');
HTTPS requests are validated; non-HTTPS requests pass through unchanged. TrustPin.setup must have been called on the underlying instance before making requests.
Constructors
- TrustPinDioInterceptor({TrustPin? instance})
-
Validates HTTPS requests against
instance(or TrustPin.shared when null). TrustPin.setup must have been called on that instance before making requests.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onError(
DioException err, ErrorInterceptorHandler handler) → void -
Called when an exception was occurred during the request.
inherited
-
onRequest(
RequestOptions options, RequestInterceptorHandler handler) → void - Called when the request is about to be sent.
-
onResponse(
Response response, ResponseInterceptorHandler handler) → void -
Called when the response is about to be resolved.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited