TrustPinLogLevel enum
Log levels for controlling TrustPin SDK output verbosity.
Values
- none → const TrustPinLogLevel
-
No logging output.
const TrustPinLogLevel('none') - error → const TrustPinLogLevel
-
Errors only. Recommended for production.
const TrustPinLogLevel('error') - info → const TrustPinLogLevel
-
Errors and informational messages.
const TrustPinLogLevel('info') - debug → const TrustPinLogLevel
-
All messages, including debug. For development only.
const TrustPinLogLevel('debug')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
The string value representation of this log level.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
TrustPinLogLevel> - A constant List of the values in this enum, in order of their declaration.